lavalink_rs.model.client API documentation

# lavalink_rs.model.client

class NodeDistributionStrategy:
def sharded() -> lavalink_rs.model.client.NodeDistributionStrategy:
def round_robin() -> lavalink_rs.model.client.NodeDistributionStrategy:
def main_fallback() -> lavalink_rs.model.client.NodeDistributionStrategy:
def lowest_load() -> lavalink_rs.model.client.NodeDistributionStrategy:
def highest_free_memory() -> lavalink_rs.model.client.NodeDistributionStrategy:
def custom( func: Callable[[LavalinkClient, Union[GuildId, int]], Awaitable[int]]) -> lavalink_rs.model.client.NodeDistributionStrategy: